==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebPaginatorDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { WebDisplayDensityBaseElementDescription } from "./WebDisplayDensityBaseElementDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebPaginatorDescription = /*@__PURE__*/ (() => {
    class WebPaginatorDescription extends WebDisplayDensityBaseElementDescription {
        constructor() {
            super();
            this.u = 0;
            this.s = 0;
            this.t = 0;
            this.v = 0;
            this.m = null;
            this.o = null;
            this.q = null;
            this.aa = null;
            this.ae = null;
            this.ab = null;
            this.ac = null;
            this.ad = null;
        }
        get_type() {
            return "WebPaginator";
        }
        get totalPages() {
            return this.u;
        }
        set totalPages(a) {
            this.u = a;
            this.g("TotalPages");
        }
        get page() {
            return this.s;
        }
        set page(a) {
            this.s = a;
            this.g("Page");
        }
        get perPage() {
            return this.t;
        }
        set perPage(a) {
            this.t = a;
            this.g("PerPage");
        }
        get totalRecords() {
            return this.v;
        }
        set totalRecords(a) {
            this.v = a;
            this.g("TotalRecords");
        }
        get selectOptions() {
            return this.m;
        }
        set selectOptions(a) {
            this.m = a;
            this.g("SelectOptions");
        }
        get overlaySettings() {
            return this.o;
        }
        set overlaySettings(a) {
            this.o = a;
            this.g("OverlaySettings");
        }
        get resourceStrings() {
            return this.q;
        }
        set resourceStrings(a) {
            this.q = a;
            this.g("ResourceStrings");
        }
        get name() {
            return this.aa;
        }
        set name(a) {
            this.aa = a;
            this.g("Name");
        }
        get perPageChangeRef() {
            return this.ae;
        }
        set perPageChangeRef(a) {
            this.ae = a;
            this.g("PerPageChangeRef");
        }
        get pageChangeRef() {
            return this.ab;
        }
        set pageChangeRef(a) {
            this.ab = a;
            this.g("PageChangeRef");
        }
        get pagingRef() {
            return this.ac;
        }
        set pagingRef(a) {
            this.ac = a;
            this.g("PagingRef");
        }
        get pagingDoneRef() {
            return this.ad;
        }
        set pagingDoneRef(a) {
            this.ad = a;
            this.g("PagingDoneRef");
        }
    }
    WebPaginatorDescription.$t = markType(WebPaginatorDescription, 'WebPaginatorDescription', WebDisplayDensityBaseElementDescription.$);
    return WebPaginatorDescription;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebPaginatorDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebPaginatorDescription = /*@__PURE__*/ (() => {
    class WebPaginatorDescription extends Description {
        constructor() {
            super();
            this.p = 0;
            this.n = 0;
            this.o = 0;
            this.q = 0;
            this.h = null;
            this.j = null;
            this.l = null;
            this.v = null;
            this.z = null;
            this.w = null;
            this.x = null;
            this.y = null;
        }
        get_type() {
            return "WebPaginator";
        }
        get type() {
            return this.get_type();
        }
        get totalPages() {
            return this.p;
        }
        set totalPages(a) {
            this.p = a;
            this.g("TotalPages");
        }
        get page() {
            return this.n;
        }
        set page(a) {
            this.n = a;
            this.g("Page");
        }
        get perPage() {
            return this.o;
        }
        set perPage(a) {
            this.o = a;
            this.g("PerPage");
        }
        get totalRecords() {
            return this.q;
        }
        set totalRecords(a) {
            this.q = a;
            this.g("TotalRecords");
        }
        get selectOptions() {
            return this.h;
        }
        set selectOptions(a) {
            this.h = a;
            this.g("SelectOptions");
        }
        get overlaySettings() {
            return this.j;
        }
        set overlaySettings(a) {
            this.j = a;
            this.g("OverlaySettings");
        }
        get resourceStrings() {
            return this.l;
        }
        set resourceStrings(a) {
            this.l = a;
            this.g("ResourceStrings");
        }
        get name() {
            return this.v;
        }
        set name(a) {
            this.v = a;
            this.g("Name");
        }
        get perPageChangeRef() {
            return this.z;
        }
        set perPageChangeRef(a) {
            this.z = a;
            this.g("PerPageChangeRef");
        }
        get pageChangeRef() {
            return this.w;
        }
        set pageChangeRef(a) {
            this.w = a;
            this.g("PageChangeRef");
        }
        get pagingRef() {
            return this.x;
        }
        set pagingRef(a) {
            this.x = a;
            this.g("PagingRef");
        }
        get pagingDoneRef() {
            return this.y;
        }
        set pagingDoneRef(a) {
            this.y = a;
            this.g("PagingDoneRef");
        }
    }
    WebPaginatorDescription.$t = markType(WebPaginatorDescription, 'WebPaginatorDescription', Description.$);
    return WebPaginatorDescription;
})();
